pub enum AttrValue {
Array(Vec<Node>),
String(String),
Number(f64),
Integer(i64),
Boolean(bool),
Null,
}Expand description
Represents a typed attribute value that can be returned from or passed to attr/set_attr methods.
Variants
Implementations
Sourceimpl AttrValue
impl AttrValue
Sourcepub fn is_integer(&self) -> bool
pub fn is_integer(&self) -> bool
Returns true if the attribute value is an integer.
Sourcepub fn is_boolean(&self) -> bool
pub fn is_boolean(&self) -> bool
Returns true if the attribute value is a boolean.