Node

Enum Node 

pub enum Node {
Show 33 variants Blockquote(Blockquote), Break(Break), Definition(Definition), Delete(Delete), Heading(Heading), Emphasis(Emphasis), Footnote(Footnote), FootnoteRef(FootnoteRef), Html(Html), Yaml(Yaml), Toml(Toml), Image(Image), ImageRef(ImageRef), CodeInline(CodeInline), MathInline(MathInline), Link(Link), LinkRef(LinkRef), Math(Math), List(List), TableAlign(TableAlign), TableRow(TableRow), TableCell(TableCell), Code(Code), Strong(Strong), HorizontalRule(HorizontalRule), MdxFlowExpression(MdxFlowExpression), MdxJsxFlowElement(MdxJsxFlowElement), MdxJsxTextElement(MdxJsxTextElement), MdxTextExpression(MdxTextExpression), MdxJsEsm(MdxJsEsm), Text(Text), Fragment(Fragment), Empty,
}

Variants



Blockquote(Blockquote)



Break(Break)



Definition(Definition)



Delete(Delete)



Heading(Heading)



Emphasis(Emphasis)



Footnote(Footnote)



FootnoteRef(FootnoteRef)



Html(Html)



Yaml(Yaml)



Toml(Toml)



Image(Image)



ImageRef(ImageRef)



CodeInline(CodeInline)



MathInline(MathInline)



LinkRef(LinkRef)



Math(Math)



List(List)



TableAlign(TableAlign)



TableRow(TableRow)



TableCell(TableCell)



Code(Code)



Strong(Strong)



HorizontalRule(HorizontalRule)



MdxFlowExpression(MdxFlowExpression)



MdxJsxFlowElement(MdxJsxFlowElement)



MdxJsxTextElement(MdxJsxTextElement)



MdxTextExpression(MdxTextExpression)



MdxJsEsm(MdxJsEsm)



Text(Text)



Fragment(Fragment)



Empty

Implementations

Source

impl Node

pub fn map_values<E, F>(&self, f: &mut F) -> Result<Node, E>
where E: Error, F: FnMut(&Node) -> Result<Node, E>,

pub fn to_fragment(&self) -> Node

pub fn apply_fragment(&mut self, fragment: Node)

pub fn to_string_with(&self, options: &RenderOptions) -> String

pub fn node_values(&self) -> Vec<Node>

pub fn find_at_index(&self, index: usize) -> Option<Node>

pub fn value(&self) -> String

pub fn name(&self) -> SmolStr

pub fn children(&self) -> Vec<Node>

Get the children nodes of the current node.

pub fn set_position(&mut self, pos: Option<Position>)

pub fn position(&self) -> Option<Position>

pub fn is_empty(&self) -> bool

pub fn is_fragment(&self) -> bool

pub fn is_empty_fragment(&self) -> bool

pub fn is_inline_code(&self) -> bool

pub fn is_inline_math(&self) -> bool

pub fn is_strong(&self) -> bool

pub fn is_list(&self) -> bool

pub fn is_emphasis(&self) -> bool

pub fn is_delete(&self) -> bool

pub fn is_text(&self) -> bool

pub fn is_image(&self) -> bool

pub fn is_horizontal_rule(&self) -> bool

pub fn is_blockquote(&self) -> bool

pub fn is_html(&self) -> bool

pub fn is_footnote(&self) -> bool

pub fn is_mdx_jsx_flow_element(&self) -> bool

pub fn is_mdx_js_esm(&self) -> bool

pub fn is_toml(&self) -> bool

pub fn is_yaml(&self) -> bool

pub fn is_break(&self) -> bool

pub fn is_mdx_text_expression(&self) -> bool

pub fn is_footnote_ref(&self) -> bool

pub fn is_image_ref(&self) -> bool

pub fn is_mdx_jsx_text_element(&self) -> bool

pub fn is_math(&self) -> bool

pub fn is_mdx_flow_expression(&self) -> bool

pub fn is_definition(&self) -> bool

pub fn is_table_align(&self) -> bool

pub fn is_code(&self, lang: Option<SmolStr>) -> bool

pub fn is_heading(&self, depth: Option<u8>) -> bool

pub fn with_value(&self, value: &str) -> Self

pub fn with_children_value(&self, value: &str, index: usize) -> Self

pub fn attr(&self, attr: &str) -> Option<AttrValue>

Returns the value of the specified attribute, if present.

pub fn set_attr(&mut self, attr: &str, value: impl Into<AttrValue>)

Sets the value of the specified attribute for the node, if supported.