ColorTheme

Struct ColorTheme 

pub struct ColorTheme<'a> {
Show 16 fields pub heading: (Cow<'a, str>, Cow<'a, str>), pub code: (Cow<'a, str>, Cow<'a, str>), pub code_inline: (Cow<'a, str>, Cow<'a, str>), pub emphasis: (Cow<'a, str>, Cow<'a, str>), pub strong: (Cow<'a, str>, Cow<'a, str>), pub link: (Cow<'a, str>, Cow<'a, str>), pub link_url: (Cow<'a, str>, Cow<'a, str>), pub image: (Cow<'a, str>, Cow<'a, str>), pub blockquote_marker: (Cow<'a, str>, Cow<'a, str>), pub delete: (Cow<'a, str>, Cow<'a, str>), pub horizontal_rule: (Cow<'a, str>, Cow<'a, str>), pub html: (Cow<'a, str>, Cow<'a, str>), pub frontmatter: (Cow<'a, str>, Cow<'a, str>), pub list_marker: (Cow<'a, str>, Cow<'a, str>), pub table_separator: (Cow<'a, str>, Cow<'a, str>), pub math: (Cow<'a, str>, Cow<'a, str>),
}
Color theme for rendering markdown nodes with optional ANSI escape codes.

Each field is a tuple of (prefix, suffix) ANSI escape code strings that wrap the corresponding markdown element during colored rendering.

Fields

heading: (Cow<'a, str>, Cow<'a, str>)code: (Cow<'a, str>, Cow<'a, str>)code_inline: (Cow<'a, str>, Cow<'a, str>)emphasis: (Cow<'a, str>, Cow<'a, str>)strong: (Cow<'a, str>, Cow<'a, str>)link: (Cow<'a, str>, Cow<'a, str>)link_url: (Cow<'a, str>, Cow<'a, str>)image: (Cow<'a, str>, Cow<'a, str>)blockquote_marker: (Cow<'a, str>, Cow<'a, str>)delete: (Cow<'a, str>, Cow<'a, str>)horizontal_rule: (Cow<'a, str>, Cow<'a, str>)html: (Cow<'a, str>, Cow<'a, str>)frontmatter: (Cow<'a, str>, Cow<'a, str>)list_marker: (Cow<'a, str>, Cow<'a, str>)table_separator: (Cow<'a, str>, Cow<'a, str>)math: (Cow<'a, str>, Cow<'a, str>)

Implementations

Source

impl ColorTheme<'_>

pub const PLAIN: ColorTheme<'static>